# coding: utf-8

"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ZSGF.Client.models.j_object_api_result import JObjectApiResult

class TestJObjectApiResult(unittest.TestCase):
    """JObjectApiResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JObjectApiResult:
        """Test JObjectApiResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JObjectApiResult`
        """
        model = JObjectApiResult()
        if include_optional:
            return JObjectApiResult(
                code = 56,
                err = '',
                data = {
                    'key' : [
                        null
                        ]
                    }
            )
        else:
            return JObjectApiResult(
        )
        """

    def testJObjectApiResult(self):
        """Test JObjectApiResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
