# coding: utf-8

# flake8: noqa
"""
    应用存储  API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ZSGF.Client.models.j_object_api_result import JObjectApiResult
